@@ -3,6 +3,7 @@ import copy
 import json
 import os
 import re
+from importlib import metadata
 from typing import Any, Callable, Literal, Optional, TypeVar, Union, cast
 from urllib.parse import urljoin
 
@@ -52,18 +53,36 @@ GET_NPM_AUTH_TOKEN_RESPONSE_FILTER_LAMBDA = lambda x: re.sub(
 
 class GableAPIClient:
     def __init__(
-        self, endpoint: Union[str, None] = None, api_key: Union[str, None] = None
+        self,
+        endpoint: Union[str, None] = None,
+        api_key: Union[str, None] = None,
+        api_headers: Union[dict, None] = None,
     ) -> None:
         # Connection settings
         if endpoint is None:
             self.endpoint = os.getenv("GABLE_API_ENDPOINT", "")
         else:
             self.endpoint = endpoint
+
         if api_key is None:
             self.api_key = os.getenv("GABLE_API_KEY", "")
         else:
             self.api_key = api_key
 
+        if api_headers is None:
+            headers: Union[str, None] = os.getenv("GABLE_API_HEADERS", "")
+            if headers:
+                try:
+                    self.api_headers = json.loads(headers)
+                except json.JSONDecodeError:
+                    raise ValueError(
+                        "GABLE_API_HEADERS environment variable is not valid JSON"
+                    )
+            else:
+                self.api_headers = {}
+        else:
+            self.api_headers = api_headers
+
     @property
     def ui_endpoint(self) -> str:
         self.validate_endpoint()
@@ -88,6 +107,21 @@ class GableAPIClient:
                     f"Gable API Endpoint must start with 'https://'. Received: {self.endpoint}"
                 )
 
+    def validate_api_headers(self):
+        if self.api_headers is None or self.api_headers == {}:
+            self.api_headers = {}
+            # No headers to validate
+            return
+        if not isinstance(self.api_headers, dict):
+            raise ValueError(
+                "API Headers must be a dictionary. Set GABLE_API_HEADERS environment variable."
+            )
+        for key, value in self.api_headers.items():
+            if not isinstance(key, str) or not isinstance(value, str):
+                raise ValueError(
+                    "API Headers must be a dictionary of string keys and string values."
+                )
+
     def _get(
         self,
         path: str,
@@ -119,7 +153,14 @@ class GableAPIClient:
 
         logger.debug(f"{method} {url}: {kwargs_copy}")
 
-        headers = {"X-API-KEY": self.api_key, "Content-Type": "application/json"}
+        headers = {
+            "X-API-KEY": self.api_key,
+            "Content-Type": "application/json",
+            "gable-client-version": metadata.version("gable")
+            or "unavailable-client-version",
+        }
+        # Merge custom headers from env
+        headers.update(self.api_headers)
 
         try:
             response = requests.request(method, url, headers=headers, **kwargs)
