@@ -2,6 +2,8 @@ from typing import Optional, Union, cast
 
 import click
 from click.core import Context as ClickContext
+from loguru import logger
+
 from gable.cli.commands.asset_plugins.avro import AvroAssetPlugin
 from gable.cli.commands.asset_plugins.mssql import MsSQLAssetPlugin
 from gable.cli.commands.asset_plugins.mysql import MySQLAssetPlugin
@@ -34,7 +36,6 @@ from gable.openapi import (
     ResponseType,
     SourceType,
 )
-from loguru import logger
 
 
 @click.command(
@@ -170,6 +171,7 @@ def check_data_asset(
     config_file: Optional[click.File],
     config_entrypoint_path: Optional[str],
     config_args_path: Optional[str],
+    rules_file: Optional[str],
 ) -> None:
     """Checks data asset(s) against a contract"""
     # Standardize the source type
@@ -305,6 +307,7 @@ def check_data_asset(
         asset_plugin = TypescriptAssetPlugin()
         kwargs = {
             "project_root": project_root,
+            "rules_file": rules_file,
             "library": library,
             "emitter_function": emitter_function,
             "emitter_payload_parameter": emitter_payload_parameter,
@@ -313,6 +316,7 @@ def check_data_asset(
             "node_modules_include": node_modules_include,
             "emitter_file_path": emitter_file_path,
             "emitter_location": emitter_location or emitter_file_path,
+            "exclude": exclude,
         }
         plugin_check(
             asset_plugin,
