@@ -60,9 +60,17 @@ def lineage_upload(
         raise click.ClickException(f"Invalid results file: {e}")
 
     external_component_id = getattr(lineage_obj, "external_component_id", None)
+    repo_name = getattr(lineage_obj, "name", None)
 
     run_id, presigned_url = start_sca_run(
-        client, project_root, "upload", None, None, external_component_id, upload_type
+        client,
+        project_root,
+        "upload",
+        None,
+        None,
+        external_component_id,
+        upload_type,
+        repo_name,
     )
     upload_sca_results(run_id, presigned_url, lineage_obj)
     click.echo(
