@@ -12,7 +12,6 @@ from gable.openapi import (
     ContractSpec,
     ContractStatus,
     PostContractRequest,
-    Status,
 )
 from gable.sdk.models import ExternalContractInput, GitMetadata
 
@@ -81,7 +80,7 @@ def contract_files_to_contract_inputs(
 
                 contract_input = ExternalContractInput(
                     version="0.0.1",  # This should be server calculated
-                    status=Status("ACTIVE"),
+                    status=ContractStatus.ACTIVE,
                     contractSpec=ContractSpec(**contract),
                     gitMetadata=GitMetadata(
                         gitHash=git_info["gitHash"],
