@@ -358,37 +358,6 @@ def gather_python_asset_data(
     return source_names, schema_contents
 
 
-def gather_typescript_asset_data(
-    library: Optional[str],
-    node_modules_include: Optional[str],
-    project_root: str,
-    emitter_file_path: Optional[str],
-    emitter_function: Optional[str],
-    emitter_payload_parameter: Optional[str],
-    emitter_name_parameter: Optional[str],
-    event_name_key: Optional[str],
-    client: GableAPIClient,
-) -> Tuple[str, dict[str, dict[str, Any]]]:
-    prepare_npm_environment(client)
-    # Run SCA, get back the results
-    (sca_results, sca_prime_results) = run_sca_typescript(
-        library,
-        node_modules_include,
-        project_root,
-        emitter_file_path,
-        emitter_function,
-        emitter_payload_parameter,
-        event_name_key,
-        emitter_name_parameter,
-        None,  # No exclude paths for now
-        client,
-    )
-    return get_git_repo(project_root), {
-        **get_event_schemas_from_sca_results(sca_results),
-        **sca_prime_results,
-    }
-
-
 def get_event_schemas_from_sca_results(sca_results: str) -> dict[str, dict[str, Any]]:
     try:
         # sca_results is a json string which should be an obj mapping event name to schema
