@@ -104,7 +104,8 @@ def ensure_npm_and_maybe_start_run(
         output,
         include_unchanged_assets,
         None,
-        upload_type=Type.CODE,
+        Type.CODE,
+        None,
     )
     logger.debug(f"Starting static code analysis run with ID: {run_id}")
     return run_id, presigned_url
