@@ -477,7 +477,7 @@ def get_sca_prime_results(
                     post_metrics_request = CreateTelemetryRequest(
                         id=None,
                         data=metrics,
-                        type=TelemetryType(root="SCA_PRIME"),
+                        type=TelemetryType.SCA_PRIME,
                     )
                     post_metrics_response, post_metrics_success = client.post_telemetry(
                         post_metrics_request
