@@ -36,6 +36,7 @@ def start_sca_run(
     include_unchanged_assets: bool | None,
     external_component_id: str | None,
     upload_type: Type | None,
+    repo_name: str | None,
 ) -> Tuple[str, S3PresignedUrl]:
     """Call the SCA start run API to get the S3 presigned URL to upload the SCA results
 
@@ -80,6 +81,7 @@ def start_sca_run(
                 repo_commit=git_info["gitHash"],
                 project_root=project_root,
                 external_component_id=external_component_id,
+                repo_name=repo_name,
             ),
             sca_info=StaticAnalysisToolMetadata(
                 name=package_name,
@@ -202,6 +204,7 @@ def upload_sca_results(
             run_id=run_id,
             paths=lineage_data_file.paths,
             external_component_id=lineage_data_file.external_component_id,
+            name=lineage_data_file.name,
         )
     elif isinstance(lineage_data_file, CrossServiceDataStore):
         upload_request = CrossServiceDataStore(
